@@ -1,11 +1,21 @@
+from functools import partial
+
 from daphne.testing import DaphneProcess
+from django.contrib.staticfiles.handlers import ASGIStaticFilesHandler
 from django.core.exceptions import ImproperlyConfigured
 from django.db import connections
 from django.test.testcases import TransactionTestCase
 from django.test.utils import modify_settings
 
 from channels.routing import get_default_application
-from channels.staticfiles import StaticFilesWrapper
+
+
+def make_application(*, static_wrapper):
+    # Module-level function for pickle-ability
+    application = get_default_application()
+    if static_wrapper is not None:
+        application = static_wrapper(application)
+    return application
 
 
 class ChannelsLiveServerTestCase(TransactionTestCase):
@@ -18,7 +28,7 @@ class ChannelsLiveServerTestCase(TransactionTestCase):
 
     host = "localhost"
     ProtocolServerProcess = DaphneProcess
-    static_wrapper = StaticFilesWrapper
+    static_wrapper = ASGIStaticFilesHandler
     serve_static = True
 
     @property
@@ -43,12 +53,11 @@ class ChannelsLiveServerTestCase(TransactionTestCase):
         )
         self._live_server_modified_settings.enable()
 
-        if self.serve_static:
-            application = self.static_wrapper(get_default_application())
-        else:
-            application = get_default_application()
-
-        self._server_process = self.ProtocolServerProcess(self.host, application)
+        get_application = partial(
+            make_application,
+            static_wrapper=self.static_wrapper if self.serve_static else None,
+        )
+        self._server_process = self.ProtocolServerProcess(self.host, get_application)
         self._server_process.start()
         self._server_process.ready.wait()
         self._port = self._server_process.port.value
