@@ -4,7 +4,14 @@ from django.conf import settings
 
 def pytest_configure():
     settings.configure(
-        DATABASES={"default": {"ENGINE": "django.db.backends.sqlite3"}},
+        DATABASES={
+            "default": {
+                "ENGINE": "django.db.backends.sqlite3",
+                # Override Django’s default behaviour of using an in-memory database
+                # in tests for SQLite, since that avoids connection.close() working.
+                "TEST": {"NAME": "test_db.sqlite3"},
+            }
+        },
         INSTALLED_APPS=[
             "django.contrib.auth",
             "django.contrib.contenttypes",
